@@ -34,30 +34,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
-import javax.activation.DataSource;
-import javax.ws.rs.Consumes;
-import javax.ws.rs.WebApplicationException;
-import javax.ws.rs.client.ResponseProcessingException;
-import javax.ws.rs.core.Application;
-import javax.ws.rs.core.EntityTag;
-import javax.ws.rs.core.GenericEntity;
-import javax.ws.rs.core.HttpHeaders;
-import javax.ws.rs.core.Link;
-import javax.ws.rs.core.Link.Builder;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.MultivaluedMap;
-import javax.ws.rs.core.NewCookie;
-import javax.ws.rs.core.Response;
-import javax.ws.rs.core.Response.ResponseBuilder;
-import javax.ws.rs.core.Response.Status;
-import javax.ws.rs.core.Response.StatusType;
-import javax.ws.rs.core.UriBuilder;
-import javax.ws.rs.core.Variant;
-import javax.ws.rs.core.Variant.VariantListBuilder;
-import javax.ws.rs.ext.MessageBodyReader;
-import javax.ws.rs.ext.Provider;
-import javax.ws.rs.ext.RuntimeDelegate;
-import javax.ws.rs.ext.RuntimeDelegate.HeaderDelegate;
 import javax.xml.transform.Source;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerFactory;
@@ -65,6 +41,30 @@ import javax.xml.transform.dom.DOMResult;
 
 import org.w3c.dom.Document;
 
+import jakarta.activation.DataSource;
+import jakarta.ws.rs.Consumes;
+import jakarta.ws.rs.WebApplicationException;
+import jakarta.ws.rs.client.ResponseProcessingException;
+import jakarta.ws.rs.core.Application;
+import jakarta.ws.rs.core.EntityTag;
+import jakarta.ws.rs.core.GenericEntity;
+import jakarta.ws.rs.core.HttpHeaders;
+import jakarta.ws.rs.core.Link;
+import jakarta.ws.rs.core.Link.Builder;
+import jakarta.ws.rs.core.MediaType;
+import jakarta.ws.rs.core.MultivaluedMap;
+import jakarta.ws.rs.core.NewCookie;
+import jakarta.ws.rs.core.Response;
+import jakarta.ws.rs.core.Response.ResponseBuilder;
+import jakarta.ws.rs.core.Response.Status;
+import jakarta.ws.rs.core.Response.StatusType;
+import jakarta.ws.rs.core.UriBuilder;
+import jakarta.ws.rs.core.Variant;
+import jakarta.ws.rs.core.Variant.VariantListBuilder;
+import jakarta.ws.rs.ext.MessageBodyReader;
+import jakarta.ws.rs.ext.Provider;
+import jakarta.ws.rs.ext.RuntimeDelegate;
+import jakarta.ws.rs.ext.RuntimeDelegate.HeaderDelegate;
 import org.apache.cxf.endpoint.Endpoint;
 import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.jaxrs.provider.ProviderFactory;
@@ -77,6 +77,7 @@ import org.apache.cxf.message.Message;
 import org.apache.cxf.message.MessageImpl;
 import org.apache.cxf.staxutils.StaxUtils;
 
+import org.easymock.EasyMock;
 import org.junit.Test;
 
 import static org.junit.Assert.assertEquals;
@@ -86,10 +87,7 @@ import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertThrows;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.times;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
+
 
 @SuppressWarnings("resource") // Responses built in this test don't need to be closed
 public class ResponseImplTest {
@@ -150,12 +148,13 @@ public class ResponseImplTest {
         m.setExchange(e);
         e.setInMessage(m);
         e.setOutMessage(new MessageImpl());
-        Endpoint endpoint = mock(Endpoint.class);
-        when(endpoint.getEndpointInfo()).thenReturn(null);
-        when(endpoint.get(Application.class.getName())).thenReturn(null);
-        when(endpoint.size()).thenReturn(0);
-        when(endpoint.isEmpty()).thenReturn(true);
-        when(endpoint.get(ServerProviderFactory.class.getName())).thenReturn(factory);
+        Endpoint endpoint = EasyMock.createMock(Endpoint.class);
+        EasyMock.expect(endpoint.getEndpointInfo()).andReturn(null).anyTimes();
+        EasyMock.expect(endpoint.get(Application.class.getName())).andReturn(null);
+        EasyMock.expect(endpoint.size()).andReturn(0).anyTimes();
+        EasyMock.expect(endpoint.isEmpty()).andReturn(true).anyTimes();
+        EasyMock.expect(endpoint.get(ServerProviderFactory.class.getName())).andReturn(factory).anyTimes();
+        EasyMock.replay(endpoint);
         e.put(Endpoint.class, endpoint);
         return m;
     }
@@ -197,51 +196,58 @@ public class ResponseImplTest {
 
     @Test
     public void testHasEntityWithEmptyStreamThatIsMarkSupported() throws Exception {
-        InputStream entityStream = mock(InputStream.class);
-        when(entityStream.markSupported()).thenReturn(true);
+        InputStream entityStream = EasyMock.createStrictMock(InputStream.class);
+        EasyMock.expect(entityStream.markSupported()).andReturn(true);
         entityStream.mark(1);
-        when(entityStream.read()).thenReturn(-1);
+        EasyMock.expect(entityStream.read()).andReturn(-1);
         entityStream.reset();
+        EasyMock.replay(entityStream);
         assertFalse(new ResponseImpl(200, entityStream).hasEntity());
+        EasyMock.verify(entityStream);
     }
 
     @Test
     public void testHasEntityWithNonEmptyStreamThatIsMarkSupported() throws Exception {
-        InputStream entityStream = mock(InputStream.class);
-        when(entityStream.markSupported()).thenReturn(true);
+        InputStream entityStream = EasyMock.createStrictMock(InputStream.class);
+        EasyMock.expect(entityStream.markSupported()).andReturn(true);
         entityStream.mark(1);
-        when(entityStream.read()).thenReturn(0);
+        EasyMock.expect(entityStream.read()).andReturn(0);
         entityStream.reset();
+        EasyMock.replay(entityStream);
         assertTrue(new ResponseImpl(200, entityStream).hasEntity());
+        EasyMock.verify(entityStream);
     }
 
     @Test
     public void testHasEntityWithEmptyStreamThatIsNotMarkSupported() throws Exception {
-        InputStream entityStream = mock(InputStream.class);
-        when(entityStream.markSupported()).thenReturn(false);
-        when(entityStream.available()).thenReturn(0);
-        when(entityStream.read()).thenReturn(-1);
+        InputStream entityStream = EasyMock.createStrictMock(InputStream.class);
+        EasyMock.expect(entityStream.markSupported()).andReturn(false);
+        EasyMock.expect(entityStream.available()).andReturn(0);
+        EasyMock.expect(entityStream.read()).andReturn(-1);
+        EasyMock.replay(entityStream);
         assertFalse(new ResponseImpl(200, entityStream).hasEntity());
+        EasyMock.verify(entityStream);
     }
 
     @Test
     public void testHasEntityWithNonEmptyStreamThatIsNotMarkSupportedButIsAvailableSupported() throws Exception {
-        InputStream entityStream = mock(InputStream.class);
-        when(entityStream.markSupported()).thenReturn(false);
-        when(entityStream.available()).thenReturn(10);
+        InputStream entityStream = EasyMock.createStrictMock(InputStream.class);
+        EasyMock.expect(entityStream.markSupported()).andReturn(false);
+        EasyMock.expect(entityStream.available()).andReturn(10);
+        EasyMock.replay(entityStream);
         assertTrue(new ResponseImpl(200, entityStream).hasEntity());
+        EasyMock.verify(entityStream);
     }
 
     @Test
     public void testHasEntityWithnNonEmptyStreamThatIsNotMarkSupportedNorAvailableSupported() throws Exception {
-        InputStream entityStream = mock(InputStream.class);
-        when(entityStream.markSupported()).thenReturn(false);
-        when(entityStream.available()).thenReturn(0);
-        when(entityStream.read()).thenReturn(0);
+        InputStream entityStream = EasyMock.createStrictMock(InputStream.class);
+        EasyMock.expect(entityStream.markSupported()).andReturn(false).once();
+        EasyMock.expect(entityStream.available()).andReturn(0).once();
+        EasyMock.expect(entityStream.read()).andReturn(0).once();
+        EasyMock.replay(entityStream);
         assertTrue(new ResponseImpl(200, entityStream).hasEntity());
-        verify(entityStream, times(1)).markSupported();
-        verify(entityStream, times(1)).available();
-        verify(entityStream, times(1)).read();
+        EasyMock.verify(entityStream);
     }
 
     @Test
