@@ -31,10 +31,10 @@ import javax.net.ssl.KeyManager;
 import javax.net.ssl.KeyManagerFactory;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
-import javax.xml.ws.AsyncHandler;
-import javax.xml.ws.Endpoint;
-import javax.xml.ws.Response;
 
+import jakarta.xml.ws.AsyncHandler;
+import jakarta.xml.ws.Endpoint;
+import jakarta.xml.ws.Response;
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusFactory;
 import org.apache.cxf.configuration.jsse.TLSClientParameters;
@@ -164,7 +164,7 @@ public class SSLNettyClientTest extends AbstractBusClientServerTestBase {
         return fac.getKeyManagers();
     }
 
-    private final class MyLaterResponseHandler implements AsyncHandler<GreetMeLaterResponse> {
+    private class MyLaterResponseHandler implements AsyncHandler<GreetMeLaterResponse> {
         GreetMeLaterResponse response;
         @Override
         public void handleResponse(Response<GreetMeLaterResponse> res) {
