@@ -35,22 +35,21 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
-import javax.activation.DataHandler;
 import javax.imageio.ImageIO;
-import javax.mail.util.ByteArrayDataSource;
-import javax.ws.rs.client.Client;
-import javax.ws.rs.client.ClientBuilder;
-import javax.ws.rs.client.Entity;
-import javax.ws.rs.client.WebTarget;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.MultivaluedHashMap;
-import javax.ws.rs.core.MultivaluedMap;
-import javax.ws.rs.core.Response;
-import javax.xml.bind.JAXBContext;
-import javax.xml.bind.Unmarshaller;
 
-import com.fasterxml.jackson.jaxrs.json.JacksonJsonProvider;
+import com.fasterxml.jackson.jakarta.rs.json.JacksonJsonProvider;
 
+import jakarta.activation.DataHandler;
+import jakarta.mail.util.ByteArrayDataSource;
+import jakarta.ws.rs.client.ClientBuilder;
+import jakarta.ws.rs.client.Entity;
+import jakarta.ws.rs.client.WebTarget;
+import jakarta.ws.rs.core.MediaType;
+import jakarta.ws.rs.core.MultivaluedHashMap;
+import jakarta.ws.rs.core.MultivaluedMap;
+import jakarta.ws.rs.core.Response;
+import jakarta.xml.bind.JAXBContext;
+import jakarta.xml.bind.Unmarshaller;
 import org.apache.cxf.ext.logging.LoggingInInterceptor;
 import org.apache.cxf.ext.logging.LoggingOutInterceptor;
 import org.apache.cxf.helpers.FileUtils;
@@ -76,7 +75,6 @@ import org.apache.http.entity.mime.content.ByteArrayBody;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.util.EntityUtils;
-import org.springframework.util.Assert;
 
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -91,7 +89,6 @@ import static org.junit.Assert.assertTrue;
 
 public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
     public static final String PORT = MultipartServer.PORT;
-    public static final String PORTINV = allocatePort(JAXRSMultipartTest.class, 1);
 
     @BeforeClass
     public static void startServers() throws Exception {
@@ -184,7 +181,7 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         String address = "http://localhost:" + PORT + "/bookstore/books/attachments";
         InputStream is =
             getClass().getResourceAsStream("/org/apache/cxf/systest/jaxrs/resources/attachmentData");
-        //create a stream that sticks a bunch of data for the attachment to cause the
+        //create a stream that sticks a bunch of data for the attachement to cause the
         //server to buffer the attachment to disk.
         PushbackInputStream buf = new PushbackInputStream(is, 1024 * 20) {
             int bcount = -1;
@@ -214,83 +211,6 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         };
         doAddBook("multipart/related", address, buf, 413);
         assertEquals(orig, countTempFiles());
-    }    
-    @Test
-    public void testBookAsMassiveAttachmentInvalidPath() throws Exception {
-        int orig = countTempFiles();
-        String address = "http://localhost:" + PORT + "/INVALID/bookstore/books/attachments";
-        InputStream is =
-            getClass().getResourceAsStream("/org/apache/cxf/systest/jaxrs/resources/attachmentData");
-        //create a stream that sticks a bunch of data for the attachment to cause the
-        //server to buffer the attachment to disk.
-        PushbackInputStream buf = new PushbackInputStream(is, 1024 * 20) {
-            int bcount = -1;
-            @Override
-            public int read(byte[] b, int offset, int len) throws IOException {
-                if (bcount >= 0 && bcount < 1024 * 5000) {
-                    for (int x = 0; x < len; x++) {
-                        b[offset + x] = (byte)x;
-                    }
-                    bcount += len;
-                    return len;
-                }
-                int i = super.read(b, offset, len);
-                for (int x = 0; x < i - 5; x++) {
-                    if (b[x + offset] == '*'
-                        && b[x + offset + 1] == '*'
-                        && b[x + offset + 2] == 'D'
-                        && b[x + offset + 3] == '*'
-                        && b[x + offset + 4] == '*') {
-                        super.unread(b, x + offset + 5, i - x - 5);
-                        i = x;
-                        bcount = 0;
-                    }
-                }
-                return i;
-            }
-        };
-        doAddBook("multipart/related", address, buf, 404);
-        assertEquals(orig, countTempFiles());
-    }
-    @Test
-    public void testBookAsMassiveAttachmentInvalidPort() throws Exception {
-        String address = "http://localhost:" + PORTINV + "/bookstore/books/attachments";
-        InputStream is =
-            getClass().getResourceAsStream("/org/apache/cxf/systest/jaxrs/resources/attachmentData");
-        //create a stream that sticks a bunch of data for the attachment to cause the
-        //server to buffer the attachment to disk.
-        PushbackInputStream buf = new PushbackInputStream(is, 1024 * 20) {
-            int bcount = -1;
-            @Override
-            public int read(byte[] b, int offset, int len) throws IOException {
-                if (bcount >= 0 && bcount < 1024 * 5000) {
-                    for (int x = 0; x < len; x++) {
-                        b[offset + x] = (byte)x;
-                    }
-                    bcount += len;
-                    return len;
-                }
-                int i = super.read(b, offset, len);
-                for (int x = 0; x < i - 5; x++) {
-                    if (b[x + offset] == '*'
-                        && b[x + offset + 1] == '*'
-                        && b[x + offset + 2] == 'D'
-                        && b[x + offset + 3] == '*'
-                        && b[x + offset + 4] == '*') {
-                        super.unread(b, x + offset + 5, i - x - 5);
-                        i = x;
-                        bcount = 0;
-                    }
-                }
-                return i;
-            }
-        };
-        try {
-            doAddBook("multipart/related", address, buf, 404);
-            org.junit.Assert.fail("Should have thrown an exception");
-        } catch (Exception ex) {
-            Assert.hasText(ex.getMessage(), "Connection refused");
-        }
     }
 
     @Test
@@ -419,49 +339,6 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         doAddBook(address, "attachmentData", 200);
     }
 
-    @Test
-    public void testAddBookWithDetailsAsMultipart() throws Exception {
-        String address = "http://localhost:" + PORT + "/bookstore/books/details";
-
-        final Client client = ClientBuilder.newClient();
-        try (InputStream is = getClass()
-                .getResourceAsStream("/org/apache/cxf/systest/jaxrs/resources/attachmentData")) {
-            final MultipartBody builder = new MultipartBody(Arrays.asList(
-                new AttachmentBuilder()
-                    .mediaType("application/xml")
-                    .id("book")
-                    .object(new Book())
-                    .build(),
-                new AttachmentBuilder()
-                    .id("upfile1Detail")
-                    .object(is)
-                    .contentDisposition(new ContentDisposition("form-data; name=\"field1\";"))
-                    .build(),
-                new AttachmentBuilder()
-                    .id("upfile2Detail")
-                    .dataHandler(new DataHandler(
-                        new InputStreamDataSource(new ByteArrayInputStream(new byte[0]), "text/xml")))
-                    .contentDisposition(new ContentDisposition("form-data; name=\"field2\";"))
-                    .build(),
-                new AttachmentBuilder()
-                    .id("upfile3Detail")
-                    .dataHandler(new DataHandler(new InputStreamDataSource(
-                        new ByteArrayInputStream(new byte[0]), "text/xml")))
-                    .contentDisposition(new ContentDisposition("form-data; name=\"field3\";"))
-                    .build()));
-        
-            final Response response = client
-                .target(address)
-                .request("text/xml")
-                .post(Entity.entity(builder, "multipart/form-data"));
-
-            final Book book = response.readEntity(Book.class);
-            assertThat("Unexpected status code for response:" + response, 
-                response.getStatus(), equalTo(200));
-            assertThat(book.getName(), equalTo("upfile1Detail,upfile2Detail,upfile3Detail"));
-        }
-    }
-
     @Test
     public void testAddBookAsJAXBBody() throws Exception {
         String address = "http://localhost:" + PORT + "/bookstore/books/jaxb-body";
@@ -483,13 +360,7 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
     @Test
     public void testAddBookMixedMultiValueMapParameter() throws Exception {
         String address = "http://localhost:" + PORT + "/bookstore/books/mixedmultivaluedmap";
-
-        InputStream is = getClass().getResourceAsStream("/org/apache/cxf/systest/jaxrs/resources/attachmentFormMixed");
-        if (System.getProperty("os.name").startsWith("Windows")) {
-            is = new NoCarriageReturnFileInputStream(is);
-        } 
-
-        doAddBook("multipart/mixed", address, is, 200);
+        doAddBook("multipart/mixed", address, "attachmentFormMixed", 200);
     }
 
     @Test
@@ -1139,9 +1010,8 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         DataHandler handler = new DataHandler(new InputStreamDataSource(is1, "application/octet-stream"));
 
         Attachment att = new Attachment(headers, handler, null);
-        try (Response response = client.post(att)) {
-            assertEquals(response.getStatus(), 200);
-        }
+        Response response = client.post(att);
+        assertEquals(response.getStatus(), 200);
 
         client.close();
     }
@@ -1252,25 +1122,4 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         return str;
     }
 
-    /**
-     * Windows attachment handling
-     */
-    private static class NoCarriageReturnFileInputStream extends InputStream {
-        private final InputStream is;
-
-        NoCarriageReturnFileInputStream(InputStream is) {
-            this.is = is;
-        }
-
-        @Override
-        public int read() throws IOException {
-            int c;
-
-            do {
-                c = is.read();
-            } while(c != -1 && c == 13);
-
-            return c;
-        }
-    }
 }
